@@ -2,8 +2,23 @@ Plot2VarsVsLTime <- function(var1, var2, toptitle = '', ytitle = '', monini = 1,
                              freq = 12, nticks = NULL, limits = NULL, listexp =
                              c('exp1', 'exp2', 'exp3'), listvars = c('var1',
                              'var2'), biglab = FALSE, hlines = NULL, leg = TRUE,
-                             siglev = FALSE, sizetit = 1, fileout = 
-                             'output_plot2varsvsltime.eps', show_conf = TRUE) {
+                             siglev = FALSE, sizetit = 1, show_conf = TRUE,
+                             fileout = 'output_plot2varsvsltime.eps', 
+                             width = 8, height = 5, size_units = 'in', res = 100, ...) {
+  # Process the user graphical parameters that may be passed in the call
+  ## Graphical parameters to exclude
+  excludedArgs <- c("cex", "cex.axis", "cex.lab", "cex.main", "col", "fin", "lab", "las", "lty", "lwd", "mai", "mgp", "new", "pin", "ps", "pty")
+  userArgs <- .FilterUserGraphicArgs(excludedArgs, ...)
+
+  # If there is any filenames to store the graphics, process them
+  # to select the right device 
+  if (!is.null(fileout)) {
+    deviceInfo <- .SelectDevice(fileout = fileout, width = width, height = height, units = size_units, res = res)
+    saveToFile <- deviceInfo$fun
+    fileout <- deviceInfo$files
+  }
+
+  #
   nvars <- 2
 
   if (length(dim(var1)) != length(dim(var2))) { 
@@ -76,11 +91,22 @@ Plot2VarsVsLTime <- function(var1, var2, toptitle = '', ytitle = '', monini = 1,
   thickness[1] <- c(1)
   thickness[2] <- c(8)
   thickness[3] <- thickness[1]
+  
   #
   #  Define plot layout
   # ~~~~~~~~~~~~~~~~~~~~
   #
-  postscript(fileout, width = 550, height = 300)
+
+  # Open connection to graphical device
+  if (!is.null(fileout)) {
+    saveToFile(fileout)
+  } else if (names(dev.cur()) == 'null device') {
+    dev.new(units = size_units, res = res, width = width, height = height)
+  }
+
+  # Load the user parameters
+  par(userArgs)
+
   if (biglab) {
     par(mai = c(1.25, 1.4, 0.5, 1), mgp = c(4, 2.5, 0))
     par(cex = 1.3, cex.lab = 2, cex.axis = 1.8)
@@ -138,5 +164,7 @@ Plot2VarsVsLTime <- function(var1, var2, toptitle = '', ytitle = '', monini = 1,
     legend(1, ul, legendnames, lty = legendsty, lwd = legendthick,
            col = legendcol, cex = legsize)
   }
-  dev.off()
+
+  # If the graphic was saved to file, close the connection with the device
+  if(!is.null(fileout)) dev.off()
 }
